import { Coin, SharpCoins, SvgCoins } from "./Contracts";
export default class CryptoIcons {
    constructor();
    private coins;
    private load;
    private forEach;
    /**
     * Write the manifest file for `coins`
     *
     * @param path A string specifying where you want to save the files to.
     * @param name The name of the file to save (default is manifest.json)
     * @param callback Function that called for each `Coin` then the returned value added to manifest. (default coin)
     * @returns `CryptoIcons`
     */
    saveManifest(path: string, name?: string, callback?: (coin: Coin) => unknown): CryptoIcons;
    /**
     * Manipulating SVG elements whit SVG.JS library
     *
     * @param callback It gives you an 'coin' object whose `svgJs` is SVG.JS Container and you can manipulate svg whit it
     * @returns `CryptoIcons`
     */
    modifySVG(callback: (coin: SvgCoins) => void): CryptoIcons;
    /**
     * Process SVG image whit `sharp`
     *
     * @param callback It gives you an 'coin' object whose `svgSharp` is Sharp Object and you can process svg whit it
     * @returns `CryptoIcons`
     */
    sharp(callback: (coin: SharpCoins) => void): CryptoIcons;
    /**
     * Filter the coins that meet the condition specified in a callback function.
     *
     * @param callback Function is a predicate, to test each Coin. Return a value that coerces to true to keep the element, or to false otherwise.
     * @returns `CryptoIcons`
     */
    filter(callback: (coin: Coin) => boolean): CryptoIcons;
    /**
     * Write the svg of each coin in its own file
     *
     * @param path A string specifying where you want to save the files to.
     * @param name The name of the file to save the svg of the Coin (default is `coin.id`.svg)
     * @returns `CryptoIcons`
     */
    saveSVG(path: string, name?: (Coin: Coin) => string): CryptoIcons;
    /**
     * Reload all coins
     *
     * @returns `CryptoIcons`
     */
    reload(): CryptoIcons;
}
